@@ -36,14 +36,14 @@ get_estimates <- function(design, data = NULL, start = 1, end = length(design))
   }
   
   get_function_internal(
-    design, data, start, end, function(x) attr(x, "causal_type") %in% "estimator", NULL, "estimates_df")
+    design, data, start, end, function(x) attr(x, "causal_type") %in% "estimator", NULL, "estimates_df", step_type = "estimator")
 }
 
 #' @rdname get_functions
 #' @export
 draw_assignment <- function(design, data = NULL, start = 1, end = length(design)) {
   get_function_internal(
-    design, data, start, end, function(x) attr(x, "step_type") %in% "assignment")
+    design, data, start, end, function(x) attr(x, "step_type") %in% "assignment", step_type = "assignment")
 }
 
 #' @rdname get_functions
@@ -51,7 +51,7 @@ draw_assignment <- function(design, data = NULL, start = 1, end = length(design)
 #' @export
 draw_sample <- function(design, data = NULL, start = 1, end = length(design)) {
   get_function_internal(
-    design, data, start, end, function(x) attr(x, "step_type") %in% "sampling")
+    design, data, start, end, function(x) attr(x, "step_type") %in% "sampling", step_type = "sampling")
 }
 
 
@@ -62,7 +62,15 @@ check_design_class_single <- function(design) {
     stop("Please send a single design object to the design argument, typically created using the + operator.", call. = FALSE)
 }
 
-get_function_internal <- function(design, data = NULL, start, end, pred, results = list(current_df = 0), what = "current_df") {
+check_has_step_type <- function(design, step_type) {
+  if(!is.null(step_type)){
+    step_types <- sapply(design, function(x) attr(x, "step_type"))
+    if(!any(step_types %in% step_type))
+      stop(paste0("The design does not include any ", step_type, " steps."), call. = FALSE)
+  }
+}
+
+get_function_internal <- function(design, data = NULL, start, end, pred, results = list(current_df = 0), what = "current_df", step_type = NULL) {
   
   check_design_class_single(design)
   
@@ -83,6 +91,8 @@ get_function_internal <- function(design, data = NULL, start, end, pred, results
   
   design_subset <- Filter(pred, design[start:end])
   
+  check_has_step_type(design_subset, step_type)
+  
   ret <- run_design_internal.design(design_subset, current_df = data, results = results)[[what]]
   
   if(what == "estimates_df" && !is.null(ret$estimator_label) && typeof(ret$estimator_label) != "character"){
