@@ -2,7 +2,7 @@
 #'
 #' A researcher often has a set of diagnosands in mind to appropriately assess the quality of a design. \code{set_diagnosands} sets the default diagnosands for a design, so that later readers can assess the design on the same terms as the original author. Readers can also use \code{diagnose_design} to diagnose the design using any other set of diagnosands.
 #'
-#' @param design A design typically created using the + operator
+#' @param x A design typically created using the + operator, or a simulations data.frame created by \code{simulate_design}.
 #' @param diagnosands A set of diagnosands created by \code{\link{declare_diagnosands}}
 #'
 #' @return a design object with a diagnosand attribute
@@ -23,11 +23,19 @@
 #'
 #' \dontrun{
 #' diagnose_design(design)
+#' 
+#' simulations_df <- simulate_design(design)
+#' 
+#' simulations_df <- set_diagnosands(simulations_df, design)
+#' 
+#' diagnose_design(simulations_df)
+#' 
 #' }
 #'
 #' @export
-set_diagnosands <- function(design, diagnosands = default_diagnosands) {
-  attr(design, "diagnosands") <- diagnosands
+set_diagnosands <- function(x, diagnosands = default_diagnosands) {
+  
+  attr(x, "diagnosands") <- diagnosands
 
-  design
+  x
 }
