@@ -31,4 +31,18 @@ test_that("get_ works", {
   dat_sampled <- draw_sample(design, dat[c(1:75, 1:75), ])
   expect_equal(nrow(dat_sampled), 75)
   
-})
\ No newline at end of file
+})
+
+
+test_that("no sampling does not produce error from draw_sample", {
+  
+  design <- population + potential_outcomes + estimand
+  
+  dat <- draw_data(design)
+  
+  expect_error(draw_sample(design, data = dat), "does not include any sampling steps")
+  
+  expect_error(draw_assignment(design, data = dat), "does not include any assignment steps")
+  
+})
+
